@@ -14,24 +14,54 @@ import { Command, flags } from '@oclif/command'
 import { cli } from 'cli-ux'
 import * as semver from 'semver'
 
-import {CheCtlContext, CliContext, InfrastructureContext, OperatorImageUpgradeContext} from '../../context'
+import {
+  CheCtlContext,
+  CliContext,
+  EclipseCheContext,
+  InfrastructureContext,
+  OperatorImageUpgradeContext,
+} from '../../context'
 
 import { EclipseCheInstallerFactory } from '../../tasks/installers/eclipse-che/eclipse-che-installer-factory'
 import {
   ASSUME_YES,
   ASSUME_YES_FLAG,
+  AUTO_UPDATE_FLAG,
   BATCH,
   BATCH_FLAG,
+  CATALOG_SOURCE_NAMESPACE_FLAG,
   CHE_NAMESPACE,
-  CHE_NAMESPACE_FLAG, CHE_OPERATOR_CR_PATCH_YAML,
-  CHE_OPERATOR_CR_PATCH_YAML_FLAG, CHE_OPERATOR_IMAGE, CHE_OPERATOR_IMAGE_FLAG, LISTR_RENDERER, LISTR_RENDERER_FLAG,
+  CHE_NAMESPACE_FLAG,
+  CHE_OPERATOR_CR_PATCH_YAML,
+  CHE_OPERATOR_CR_PATCH_YAML_FLAG,
+  CHE_OPERATOR_IMAGE,
+  CHE_OPERATOR_IMAGE_FLAG,
+  LISTR_RENDERER,
+  LISTR_RENDERER_FLAG,
+  OLM_CHANNEL,
+  OLM_CHANNEL_FLAG,
+  PACKAGE_MANIFEST,
+  PACKAGE_MANIFEST_FLAG,
   SKIP_DEV_WORKSPACE,
-  SKIP_DEV_WORKSPACE_FLAG, SKIP_KUBE_HEALTHZ_CHECK,
-  SKIP_KUBE_HEALTHZ_CHECK_FLAG, SKIP_VERSION_CHECK, SKIP_VERSION_CHECK_FLAG,
+  SKIP_DEV_WORKSPACE_FLAG,
+  SKIP_KUBE_HEALTHZ_CHECK,
+  SKIP_KUBE_HEALTHZ_CHECK_FLAG,
+  SKIP_VERSION_CHECK,
+  SKIP_VERSION_CHECK_FLAG,
+  STARTING_CSV_FLAG,
   TELEMETRY,
   TELEMETRY_FLAG,
   TEMPLATES,
   TEMPLATES_FLAG,
+  CATALOG_SOURCE_NAME,
+  AUTO_UPDATE,
+  STARTING_CSV,
+  CATALOG_SOURCE_NAMESPACE,
+  CATALOG_SOURCE_NAME_FLAG,
+  CATALOG_SOURCE_YAML_FLAG,
+  CATALOG_SOURCE_YAML,
+  CATALOG_SOURCE_IMAGE_FLAG,
+  CATALOG_SOURCE_IMAGE, checkFlagsCompatability,
 } from '../../flags'
 import {EclipseChe} from '../../tasks/installers/eclipse-che/eclipse-che'
 import {DEFAULT_ANALYTIC_HOOK_NAME} from '../../constants'
@@ -43,6 +73,8 @@ import {
 } from '../../utils/command-utils'
 import {CommonTasks} from '../../tasks/common-tasks'
 import {getProjectName, getProjectVersion, newListr} from '../../utils/utls'
+import {KubeClient} from '../../api/kube-client'
+import {Che} from '../../utils/che'
 
 export default class Update extends Command {
   static description = `Update ${EclipseChe.PRODUCT_NAME} server.`
@@ -54,6 +86,14 @@ export default class Update extends Command {
     'dsc server:update -n eclipse-che',
     `\n# Update ${EclipseChe.PRODUCT_NAME} and update its configuration in the custom resource:\n` +
     `dsc server:update --${CHE_OPERATOR_CR_PATCH_YAML_FLAG} patch.yaml`,
+    `\n# Update ${EclipseChe.PRODUCT_NAME} from the provided channel:\n` +
+    'dsc server:update --olm-channel next',
+    `\n# Update ${EclipseChe.PRODUCT_NAME} from the provided CatalogSource and channel:\n` +
+    'dsc server:update --olm-channel fast --catalog-source-name MyCatalogName --catalog-source-namespace MyCatalogNamespace',
+    `\n# Create CatalogSource based on provided image and update ${EclipseChe.PRODUCT_NAME} from it:\n` +
+    'dsc server:update --olm-channel latest --catalog-source-image MyCatalogImage',
+    `\n# Create a CatalogSource defined in yaml file and update ${EclipseChe.PRODUCT_NAME} from it:\n` +
+    'dsc server:update --olm-channel stable --catalog-source-yaml PATH_TO_CATALOG_SOURCE_YAML',
   ]
 
   static flags: flags.Input<any> = {
@@ -69,6 +109,15 @@ export default class Update extends Command {
     [SKIP_VERSION_CHECK_FLAG]: SKIP_VERSION_CHECK,
     [TELEMETRY_FLAG]: TELEMETRY,
     [LISTR_RENDERER_FLAG]: LISTR_RENDERER,
+    // OLM flags
+    [OLM_CHANNEL_FLAG]: OLM_CHANNEL,
+    [PACKAGE_MANIFEST_FLAG]: PACKAGE_MANIFEST,
+    [CATALOG_SOURCE_NAMESPACE_FLAG]: CATALOG_SOURCE_NAMESPACE,
+    [CATALOG_SOURCE_NAME_FLAG]: CATALOG_SOURCE_NAME,
+    [CATALOG_SOURCE_YAML_FLAG]: CATALOG_SOURCE_YAML,
+    [CATALOG_SOURCE_IMAGE_FLAG]: CATALOG_SOURCE_IMAGE,
+    [AUTO_UPDATE_FLAG]: AUTO_UPDATE,
+    [STARTING_CSV_FLAG]: STARTING_CSV,
   }
 
   async run() {
@@ -81,6 +130,8 @@ export default class Update extends Command {
       await askForChectlUpdateIfNeeded()
     }
 
+    checkFlagsCompatability(flags)
+
     const eclipseCheInstallerInstaller = EclipseCheInstallerFactory.getInstaller()
 
     // PreUpdate tasks
@@ -101,10 +152,14 @@ export default class Update extends Command {
 
       if (!ctx[InfrastructureContext.IS_OPENSHIFT]) {
         if (!await this.checkAbilityToUpdateCheOperatorAndAskUser(flags)) {
-          // Exit
+          return
+        }
+      } else {
+        if (!await this.checkAbilityToUpdateCatalogSource(flags)) {
           return
         }
       }
+
       await updateTasks.run(ctx)
       await postUpdateTasks.run(ctx)
       this.log(getCommandSuccessMessage())
@@ -117,6 +172,56 @@ export default class Update extends Command {
     }
   }
 
+  private async checkAbilityToUpdateCatalogSource(flags: any): Promise<boolean> {
+    const ctx = CheCtlContext.get()
+    ctx[EclipseCheContext.CREATE_CATALOG_SOURCE_AND_SUBSCRIPTION] = false
+
+    const kubeClient = KubeClient.getInstance()
+    const subscription = await kubeClient.getOperatorSubscription(EclipseChe.SUBSCRIPTION, ctx[EclipseCheContext.OPERATOR_NAMESPACE])
+    if (subscription) {
+      const catalogSource = await kubeClient.getCatalogSource(subscription.spec.source, subscription.spec.sourceNamespace)
+
+      if (ctx[EclipseCheContext.CHANNEL] !== subscription.spec.channel ||
+        ctx[EclipseCheContext.CATALOG_SOURCE_NAME] !== subscription.spec.source ||
+        ctx[EclipseCheContext.CATALOG_SOURCE_NAMESPACE] !== subscription.spec.sourceNamespace ||
+        ctx[EclipseCheContext.PACKAGE_NAME] !== subscription.spec.name ||
+        ctx[EclipseCheContext.CATALOG_SOURCE_IMAGE] !== catalogSource?.spec.image ||
+        !Che.isRedHatCatalogSources(ctx[EclipseCheContext.CATALOG_SOURCE_NAME])) {
+        cli.info('CatalogSource and Subscription will be updated              :')
+        cli.info('-------------------------------------------------------------')
+        cli.info(`Current channel                 : ${subscription.spec.channel}`)
+        cli.info(`Current catalog source          : ${subscription.spec.source}`)
+        cli.info(`Current catalog source namespace: ${subscription.spec.sourceNamespace}`)
+        if (catalogSource && !Che.isRedHatCatalogSources(catalogSource.metadata.name)) {
+          cli.info(`Current catalog source image    : ${catalogSource.spec.image}`)
+        }
+        cli.info(`Current package name            : ${subscription.spec.name}`)
+        ctx[EclipseCheContext.CREATE_CATALOG_SOURCE_AND_SUBSCRIPTION] = true
+      }
+    } else {
+      cli.info('Subscription will be created  :')
+      ctx[EclipseCheContext.CREATE_CATALOG_SOURCE_AND_SUBSCRIPTION] = true
+    }
+
+    if (ctx[EclipseCheContext.CREATE_CATALOG_SOURCE_AND_SUBSCRIPTION]) {
+      cli.info('-------------------------------------------------------------')
+      cli.info(`New channel                     : ${ctx[EclipseCheContext.CHANNEL]}`)
+      cli.info(`New catalog source              : ${ctx[EclipseCheContext.CATALOG_SOURCE_NAME]}`)
+      cli.info(`New catalog source namespace    : ${ctx[EclipseCheContext.CATALOG_SOURCE_NAMESPACE]}`)
+      if (!Che.isRedHatCatalogSources(ctx[EclipseCheContext.CATALOG_SOURCE_NAME])) {
+        cli.info(`New catalog source image        : ${ctx[EclipseCheContext.CATALOG_SOURCE_IMAGE]}`)
+      }
+      cli.info(`New package name                : ${ctx[EclipseCheContext.PACKAGE_NAME]}`)
+
+      if (!flags[BATCH_FLAG] && !flags[ASSUME_YES_FLAG] && !await cli.confirm('If you want to continue - press Y')) {
+        cli.info('Update cancelled by user.')
+        return false
+      }
+    }
+
+    return true
+  }
+
   /**
    * Check whether dsc should proceed with update.
    * Asks user for confirmation (unless assume yes is provided).
